==> Paws-0.15.tar.gz: Paws-0.15/lib/Paws/RedShift/RebootCluster.pm <==

package Paws::RedShift::RebootCluster;
  use Moose;
  has ClusterIdentifier => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'RebootCluster');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::RedShift::RebootClusterResult');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'RebootClusterResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::RebootCluster - Arguments for method RebootCluster on Paws::RedShift

=head1 DESCRIPTION

This class represents the parameters used for calling the method RebootCluster on the 
Amazon Redshift service. Use the attributes of this class
as arguments to method RebootCluster.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to RebootCluster.

As an example:

  $service_obj->RebootCluster(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> ClusterIdentifier => Str

  

The cluster identifier.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method RebootCluster in L<Paws::RedShift>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.17.tar.gz: Paws-0.17/lib/Paws/RedShift/RebootCluster.pm <==

package Paws::RedShift::RebootCluster;
  use Moose;
  has ClusterIdentifier => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'RebootCluster');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::RedShift::RebootClusterResult');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'RebootClusterResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::RebootCluster - Arguments for method RebootCluster on Paws::RedShift

=head1 DESCRIPTION

This class represents the parameters used for calling the method RebootCluster on the 
Amazon Redshift service. Use the attributes of this class
as arguments to method RebootCluster.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to RebootCluster.

As an example:

  $service_obj->RebootCluster(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> ClusterIdentifier => Str

  The cluster identifier.



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method RebootCluster in L<Paws::RedShift>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
